==> lnl-3.1.8.tar.gz: lnl-3.1.8/src/amenu.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: amenu.h,v 1.10 2007/03/17 22:28:32 bowkenken Exp $
***************************************************************/

#ifndef	AMENU_H
#define	AMENU_H

/***************************************************************
* ưޡ
***************************************************************/

/* ưޡκ */
#define	AUTO_MARK_N_PER_PAGE	16
#define	AUTO_MARK_PAGE_N	10
#define	AUTO_MARK_MAX_N	(AUTO_MARK_N_PER_PAGE * AUTO_MARK_PAGE_N)

/* ȥκʸ */
#define	MSG_TTL_AUTO_MARK_MAX_LEN	128

/* ƥμκ */
#define	AUTO_MARK_APPOINT_ITEM_MAX_N	64

/***************************************************************
* ե饰
* ֤Ѥϥ֡ǡ⽤
***************************************************************/

/* ޡ˺Ƥӥޡʤ */
#define	FLG_AUTO_MARK_EDIT_CONT	(1 << 0)

/* Ǥ˥ޡƤƤ⶯Ū˥ޡʤ */
#define	FLG_AUTO_MARK_EDIT_PRIORITY	(1 << 1)

/***************************************************************
* о
***************************************************************/

typedef enum {
	AUTO_MARK_TRGT_MNSTR,
	AUTO_MARK_TRGT_ITEM,
	AUTO_MARK_TRGT_DOOR,
	AUTO_MARK_TRGT_TRAP,
	AUTO_MARK_TRGT_MBR,
	AUTO_MARK_TRGT_UNCHANGE,
	AUTO_MARK_TRGT_CLEAR,
} auto_mark_trgt_t;

/***************************************************************
* ֹ礤
***************************************************************/

typedef enum {
	AUTO_MARK_DIST_NEAR,
	AUTO_MARK_DIST_MEDIUM,
	AUTO_MARK_DIST_FAR,
} auto_mark_dist_t;

/***************************************************************
* 
***************************************************************/

typedef enum {
	AUTO_MARK_ACT_FIGHT,
	AUTO_MARK_ACT_THROW,
	AUTO_MARK_ACT_STEAL,
	AUTO_MARK_ACT_TAIL,
	AUTO_MARK_ACT_PICK_UP,
	AUTO_MARK_ACT_BREAK,
	AUTO_MARK_ACT_OPEN,
	AUTO_MARK_ACT_CLOSE,
	AUTO_MARK_ACT_JAM,
	AUTO_MARK_ACT_DISARM,
	AUTO_MARK_ACT_PEEP,
	AUTO_MARK_ACT_CHK,
} auto_mark_act_t;

/***************************************************************
* 
***************************************************************/

typedef enum {
	/* äȤᤤʪ */
	AUTO_MARK_COND_NEAREST,

	/* Ф餱 */
	AUTO_MARK_COND_DISPERSE,

	/* ƤС */
	AUTO_MARK_COND_STAGGER,

	/* ƱʪäƤ */
	AUTO_MARK_COND_OWN,
} auto_mark_cond_t;

/***************************************************************
* ưޡ
***************************************************************/

typedef struct {
	auto_mark_trgt_t	trgt;
	auto_mark_dist_t	dist;
	auto_mark_act_t	act;
	auto_mark_cond_t	cond;
	char	macro[MACRO_MAX_LEN + 1];
	unsigned long	flg;
} auto_mark_t;

#endif	/* AMENU_H */

==> lnl-3.1.10.tar.gz: lnl-3.1.10/src/amenu.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: amenu.h,v 1.12 2007/05/11 00:42:16 bowkenken Exp $
***************************************************************/

#ifndef	AMENU_H
#define	AMENU_H

/***************************************************************
* ưޡ
***************************************************************/

/* ưޡκ */
#define	AUTO_MARK_N_PER_PAGE	10
#define	AUTO_MARK_PAGE_N	5
#define	AUTO_MARK_MAX_N	(AUTO_MARK_N_PER_PAGE * AUTO_MARK_PAGE_N)

/* ȥκʸ */
#define	MSG_TTL_AUTO_MARK_MAX_LEN	128

/* ƥμκ */
#define	AUTO_MARK_APPOINT_ITEM_MAX_N	64

/***************************************************************
* ե饰
* ֤Ѥϥ֡ǡ⽤
***************************************************************/

/* ޡ˺Ƥӥޡʤ */
#define	FLG_AUTO_MARK_EDIT_CONT	(1 << 0)

/* Ǥ˥ޡƤƤ⶯Ū˥ޡʤ */
#define	FLG_AUTO_MARK_EDIT_PRIORITY	(1 << 1)

/***************************************************************
* о
***************************************************************/

typedef enum {
	AUTO_MARK_TRGT_MNSTR,
	AUTO_MARK_TRGT_ITEM,
	AUTO_MARK_TRGT_DOOR,
	AUTO_MARK_TRGT_TRAP,
	AUTO_MARK_TRGT_MBR,
	AUTO_MARK_TRGT_UNCHANGE,
	AUTO_MARK_TRGT_CLEAR,
} auto_mark_trgt_t;

/***************************************************************
* ֹ礤
***************************************************************/

typedef enum {
	AUTO_MARK_DIST_NEAR,
	AUTO_MARK_DIST_MEDIUM,
	AUTO_MARK_DIST_FAR,
} auto_mark_dist_t;

/***************************************************************
* 
***************************************************************/

typedef enum {
	AUTO_MARK_ACT_FIGHT,
	AUTO_MARK_ACT_THROW,
	AUTO_MARK_ACT_STEAL,
	AUTO_MARK_ACT_TAIL,
	AUTO_MARK_ACT_PICK_UP,
	AUTO_MARK_ACT_BREAK,
	AUTO_MARK_ACT_OPEN,
	AUTO_MARK_ACT_CLOSE,
	AUTO_MARK_ACT_JAM,
	AUTO_MARK_ACT_DISARM,
	AUTO_MARK_ACT_PEEP,
	AUTO_MARK_ACT_CHK,
} auto_mark_act_t;

/***************************************************************
* 
***************************************************************/

typedef enum {
	/* äȤᤤʪ */
	AUTO_MARK_COND_NEAREST,

	/* Ф餱 */
	AUTO_MARK_COND_DISPERSE,

	/* ƤС */
	AUTO_MARK_COND_STAGGER,

	/* ƱʪäƤ */
	AUTO_MARK_COND_OWN,

	/* 1  HP ξʤ */
	AUTO_MARK_COND_HP_MIN,

	/* 1  HP ¿ */
	AUTO_MARK_COND_HP_MAX,

	/* 1  MP ξʤ */
	AUTO_MARK_COND_MP_MIN,

	/* 1  MP ¿ */
	AUTO_MARK_COND_MP_MAX,
} auto_mark_cond_t;

/***************************************************************
* ưޡ
***************************************************************/

typedef struct {
	auto_mark_trgt_t	trgt;
	auto_mark_dist_t	dist;
	auto_mark_act_t	act;
	auto_mark_cond_t	cond;
	char	macro[MACRO_MAX_LEN + 1];
	unsigned long	flg;
} auto_mark_t;

#endif	/* AMENU_H */
